==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/admin/messages/ja/settings.php <==
<?php

return [
    '1 month' => '1ヶ月',
    '1 week' => '1週間',
    '1 year' => '1年',
    '2 weeks' => '2週間',
    '3 months' => '3ヶ月',
    '6 months' => '6ヶ月',
    '<strong>Confirm</strong> icon deletion' => '<strong>確認</strong> アイコンの削除',
    '<strong>Confirm</strong> image deletion' => '<strong>確認</strong> 画像の削除',
    '<strong>Maintenance</strong> Mode' => '<strong>メンテナンス </strong>モード',
    '<strong>Warning:</strong> All users will be immediately logged out, except admins.' => '<strong>警告: </strong>管理者を除くすべてのユーザーがすぐにログアウトされます。',
    'APC(u)' => 'APC(u)',
    'Activate' => 'アクティベート',
    'Activate maintenance mode and disable access to the platform for non-admin users?<br><br>' => 'メンテナンスモードをアクティブにし、管理者以外のユーザーのプラットフォームへのアクセスを無効にしますか?<br><br>',
    'Add OEmbed provider' => 'OEmbedプロパイダを追加する',
    'Add custom info text for maintenance mode. Displayed on the login page.' => 'メンテナンスモードのカスタム情報テキストを追加します。 ログインページに表示されます。',
    'Add new provider' => 'プロパイダを追加する',
    'Advanced Settings' => '高度な設定',
    'Allow Self-Signed Certificates?' => '自己署名証明書を許可する？',
    'Allowed file extensions' => '許可されたファイル拡張子',
    'Alphabetical' => 'アルファベット順',
    'Appearance Settings' => '外観の設定',
    'Auto format based on user language - Example: {example}' => 'ユーザー言語に基づく自動フォーマット - 例：{example}',
    'Back to overview' => '概要に戻る',
    'Base URL' => 'ベースURL',
    'Cache Backend' => 'キャッシュバックエンド',
    'Comma separated list. Leave empty to allow all.' => 'コンマ区切りリスト。すべてを許可するには空のままにします。',
    'Could not send test email.' => 'テストメールを送信できませんでした。',
    'Currently no provider active!' => '現在、有効なプロパイダはありません',
    'Currently there are {count} records in the database dating from {dating}.' => '現在{dating}からデータベースに{count}レコードがあります。',
    'Dashboard' => 'ダッシュボード',
    'Date input format' => '日付入力形式',
    'Deactivate' => '非アクティブ化',
    'Deactivate maintenance mode and enable all users to access the platform again?' => 'メンテナンスモードを無効にして、すべてのユーザーがプラットフォームに再度アクセスできるようにしますか?',
    'Default Expire Time (in seconds)' => 'デフォルトの有効期限（秒）',
    'Default Timezone' => 'デフォルトのタイムゾーン',
    'Default language' => 'デフォルト言語',
    'Default pagination size (Entries per page)' => 'デフォルトのページネーション数（ページあたりのエントリ数）',
    'Default stream content order' => 'デフォルトのストリームコンテンツ順序',
    'Delete' => '削除',
    'Display Name (Format)' => '表示名（形式）',
    'Dropdown space order' => 'スペースのドロップダウンの並び順',
    'E-Mail' => 'Eメール',
    'E-Mail sender address' => 'メールアドレス',
    'E-Mail sender name' => 'メール送信者名',
    'E.g. http://example.com/humhub' => '例）http://example.com/humhub',
    'Edit OEmbed provider' => 'OEmbedプロパイダを編集する',
    'Enable maintenance mode' => 'メンテナンスモードを有効にする',
    'Enable user friendship system' => 'ユーザーフレンドシップシステムを有効にする',
    'Enabled' => '使用可能',
    'Enabled OEmbed providers' => '有効になっているOEmbedプロパイダ',
    'Encryption' => '暗号化',
    'Endpoint Url' => 'エンドポイントURL',
    'Exclude media files from stream attachment list' => 'ストリーム添付ファイルリストからメディアファイルを除外する',
    'File' => 'ファイル',
    'Firstname Lastname (e.g. John Doe)' => '名前＋苗字（例： John Doe）',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => '固定フォーマット（dd / mm / yyyy） - 例：{example}',
    'Friendship' => 'フレンドシップ',
    'General' => '基本',
    'General Settings' => '基本設定',
    'HTML tracking code' => 'HTMLのトラッキングコード',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'ここでは、ソーシャルネットワークの登録動作や追加のユーザー設定を行うことができます。',
    'Here you can configure basic settings of your social network.' => 'ここでは、ソーシャルネットワークの基本的な設定を行うことができます。',
    'Horizontal scrolling images on a mobile device' => 'モバイル端末では画像を横スクロールにする',
    'Icon upload' => 'アイコンのアップロード',
    'Last visit' => '最後の訪問',
    'Logo upload' => 'ロゴのアップロード',
    'Mail Transport Type' => 'メールのトランスポートタイプ',
    'Maintenance mode' => 'メンテナンスモード',
    'Maximum allowed age for logs.' => 'ログの最大許容寿命',
    'Maximum upload file size (in MB)' => 'アップロードするファイルの最大サイズ（MB単位）',
    'Mobile appearance' => 'モバイル端末での外観',
    'Name of the application' => 'ソーシャルネットワークの名前',
    'No Proxy Hosts' => 'プロキシホストがない',
    'No caching' => 'キャッシングなし',
    'Notification Settings' => '通知の設定',
    'Old logs can significantly increase the size of your database while providing little information.' => '古いログは、ほとんど情報を提供しないでデータベースのサイズを大幅に増やすことができます。',
    'PHP APC(u) Extension missing - Type not available!' => 'PHP APC(u) 拡張子がありません - 型が利用できません。',
    'PHP reported a maximum of {maxUploadSize} MB' => 'PHPの最大ファイル容量は {maxUploadSize}MBに設定されている',
    'Password' => 'パスワード',
    'Port' => 'ポート',
    'Port number' => 'ポート番号',
    'Prevent client caching of following scripts' => '以下のスクリプトのクライアントキャッシュを防止',
    'Redis' => 'Redis',
    'Reported database time: {dateTime}' => '報告されたデータベース時間：{dateTime}',
    'SMTP Options' => 'SMTPオプション',
    'Save' => '保存',
    'Save & Flush Caches' => '保存してキャッシュをクリア',
    'Save & Test' => '保存してテストメールを送信',
    'Saved' => '保存完了',
    'Saved and flushed cache' => '保存しキャッシュをクリア',
    'Saved and sent test email to: {address}' => '保存してテストメールを送信：{address}',
    'Server' => 'サーバー',
    'Server Timezone' => 'サーバーのタイムゾーン',
    'Show introduction tour for new users' => '新規ユーザーのための機能紹介ツアーを表示',
    'Show user profile post form on dashboard' => 'ユーザープロフィール投稿をダッシュボードに表示する',
    'Sort by creation date' => '作成日順で並べる',
    'Sort by update date' => '更新日順で並べる',
    'Test message' => 'テスト メッセージ',
    'Theme' => 'テーマ',
    'These settings refer to advanced topics of your social network.' => 'ここでは、ソーシャルネットワークの高度な設定を行うことができます。',
    'These settings refer to the appearance of your social network.' => 'ここでは、ソーシャルネットワークの外観の設定を行うことができます。',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => 'URLのプレースホルダに％url％を使用します。書式はJSONである必要があります。 （例：http://www.youtube.com/oembed?url=%url%&amp;format=json）',
    'Use X-Sendfile for File Downloads' => 'ファイルダウンロードのためにX-Sendfileを使用する',
    'Use the default swipe to show sidebar on a mobile device' => 'サイドバーを表示するためにスワイプを使用する',
    'User' => 'ユーザー',
    'User Settings' => 'ユーザー設定',
    'Username' => 'ユーザー名',
    'Username (e.g. john)' => 'ユーザー名（例：john）',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => 'すべてのレンダリングされたページに追加される統計HTMLコードスニペットを追加できます。',
    'You\'re using no icon at the moment. Upload your logo now.' => '現在、アイコンを使用していません。今すぐアイコンをアップロードしてください。',
    'You\'re using no logo at the moment. Upload your logo now.' => '現在、ロゴを使用していません。今すぐロゴをアップロードしてください。',
    'never' => '保存しない',
    'Access Token' => '',
    'Access token is not provided yet.' => '',
    'E-Mail reply-to' => '',
    'Embedded content requires the user\'s consent to be loaded' => '',
    'Optional. Default reply address for system emails like notifications.' => '',
    'Provider Name' => '',
    'Regular expression by which the link match will be checked.' => '',
    'Url Pattern' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/admin/messages/ja/settings.php <==
<?php

return [
    '1 month' => '1ヶ月',
    '1 week' => '1週間',
    '1 year' => '1年',
    '2 weeks' => '2週間',
    '3 months' => '3ヶ月',
    '6 months' => '6ヶ月',
    '<strong>Confirm</strong> icon deletion' => '<strong>確認</strong> アイコンの削除',
    '<strong>Confirm</strong> image deletion' => '<strong>確認</strong> 画像の削除',
    '<strong>Maintenance</strong> Mode' => '<strong>メンテナンス </strong>モード',
    '<strong>Warning:</strong> All users will be immediately logged out, except admins.' => '<strong>警告: </strong>管理者を除くすべてのユーザーがすぐにログアウトされます。',
    'Access Token' => 'アクセス Token',
    'Access token is not provided yet.' => 'アクセス Tokenはまだ提供されていません。',
    'Activate' => '作動させる',
    'Activate maintenance mode and disable access to the platform for non-admin users?<br><br>' => 'メンテナンスモードをアクティブにし、管理者以外のユーザーのプラットフォームへのアクセスを無効にしますか?<br><br>',
    'Add OEmbed provider' => 'OEmbedプロパイダを追加する',
    'Add custom info text for maintenance mode. Displayed on the login page.' => 'メンテナンスモードのカスタム情報テキストを追加します。 ログインページに表示されます。',
    'Add new provider' => 'プロパイダを追加する',
    'Advanced Settings' => '高度な設定',
    'Allow Self-Signed Certificates?' => '自己署名証明書を許可する？',
    'Allowed file extensions' => '許可されたファイル拡張子',
    'Alphabetical' => 'アルファベット順',
    'Appearance Settings' => '外観の設定',
    'Auto format based on user language - Example: {example}' => 'ユーザー言語に基づく自動フォーマット - 例：{example}',
    'Back to overview' => '概要に戻る',
    'Base URL' => 'ベースURL',
    'Comma separated list. Leave empty to allow all.' => 'コンマ区切りリスト。すべてを許可するには空のままにします。',
    'Configuration (Use settings from configuration file)' => '構成 (構成ファイルの設定を使用)',
    'Could not send test email.' => 'テストメールを送信できませんでした。',
    'Currently no provider active!' => '現在、有効なプロパイダはありません',
    'Currently there are {count} records in the database dating from {dating}.' => '現在{dating}からデータベースに{count}レコードがあります。',
    'Custom DSN' => 'カスタム DSN',
    'DSN' => 'DSN',
    'DSN Examples:' => 'DSN 例：',
    'Dashboard' => 'ダッシュボード',
    'Date input format' => '日付入力形式',
    'Deactivate' => '非アクティブ化',
    'Deactivate maintenance mode and enable all users to access the platform again?' => 'メンテナンスモードを無効にして、すべてのユーザーがプラットフォームに再度アクセスできるようにしますか?',
    'Default Timezone' => 'デフォルトのタイムゾーン',
    'Default language' => 'デフォルト言語',
    'Default pagination size (Entries per page)' => 'デフォルトのページネーション数（ページあたりのエントリ数）',
    'Default stream content order' => 'デフォルトのストリームコンテンツ順序',
    'Delete' => '削除',
    'Dropdown space order' => 'スペースのドロップダウンの並び順',
    'E-Mail' => 'Eメール',
    'E-Mail reply-to' => 'メールの返信先',
    'E-Mail sender address' => 'メールアドレス',
    'E-Mail sender name' => 'メール送信者名',
    'E.g. http://example.com/humhub' => '例）http://example.com/humhub',
    'Edit OEmbed provider' => 'OEmbedプロパイダを編集する',
    'Embedded content requires the user\'s consent to be loaded' => '埋め込みコンテンツを読み込むには、ユーザーの同意が必要です',
    'Enable maintenance mode' => 'メンテナンスモードを有効にする',
    'Enable user friendship system' => 'ユーザーフレンドシップシステムを有効にする',
    'Enabled' => '使用可能',
    'Enabled OEmbed providers' => '有効になっているOEmbedプロパイダ',
    'Endpoint Url' => 'エンドポイントURL',
    'Exclude media files from stream attachment list' => 'ストリーム添付ファイルリストからメディアファイルを除外する',
    'Firstname Lastname (e.g. John Doe)' => '名前＋苗字（例： John Doe）',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => '固定フォーマット（dd / mm / yyyy） - 例：{example}',
    'Friendship' => 'フレンドシップ',
    'General' => '基本',
    'General Settings' => '基本設定',
    'HTML tracking code' => 'HTMLのトラッキングコード',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'ここでは、ソーシャルネットワークの登録動作や追加のユーザー設定を行うことができます。',
    'Here you can configure basic settings of your social network.' => 'ここでは、ソーシャルネットワークの基本的な設定を行うことができます。',
    'Horizontal scrolling images on a mobile device' => 'モバイル端末では画像を横スクロールにする',
    'Icon upload' => 'アイコンのアップロード',
    'Last visit' => '最後の訪問',
    'Logo upload' => 'ロゴのアップロード',
    'Mail Transport Type' => 'メールのトランスポートタイプ',
    'Maintenance mode' => 'メンテナンスモード',
    'Maximum allowed age for logs.' => 'ログの最大許容寿命',
    'Maximum upload file size (in MB)' => 'アップロードするファイルの最大サイズ（MB単位）',
    'Mobile appearance' => 'モバイル端末での外観',
    'Name of the application' => 'ソーシャルネットワークの名前',
    'No Delivery (Debug Mode, Save as file)' => '配信はありません (デバッグ モード、ファイルとして保存)',
    'No Proxy Hosts' => 'プロキシホストがない',
    'Notification Settings' => '通知の設定',
    'Old logs can significantly increase the size of your database while providing little information.' => '古いログは、ほとんど情報を提供しないでデータベースのサイズを大幅に増やすことができます。',
    'Optional. Default reply address for system emails like notifications.' => 'オプション。 通知などのシステム メールのデフォルトの返信アドレス。',
    'PHP (Use settings of php.ini file)' => 'PHP (php.ini ファイルの設定を使用)',
    'PHP reported a maximum of {maxUploadSize} MB' => 'PHPの最大ファイル容量は {maxUploadSize}MBに設定されている',
    'Password' => 'パスワード',
    'Port' => 'ポート',
    'Port number' => 'ポート番号',
    'Provider Name' => 'プロバイダ名',
    'Regular expression by which the link match will be checked.' => 'リンクの一致をチェックする正規表現。',
    'Reported database time: {dateTime}' => '報告されたデータベース時間：{dateTime}',
    'Save' => '保存',
    'Save & Flush Caches' => '保存してキャッシュをクリア',
    'Save & Test' => '保存してテストメールを送信',
    'Saved' => '保存完了',
    'Saved and flushed cache' => '保存しキャッシュをクリア',
    'Saved and sent test email to: {address}' => '保存してテストメールを送信：{address}',
    'Server' => 'サーバー',
    'Server Timezone' => 'サーバーのタイムゾーン',
    'Show introduction tour for new users' => '新規ユーザーのための機能紹介ツアーを表示',
    'Show user profile post form on dashboard' => 'ユーザープロフィール投稿をダッシュボードに表示する',
    'Sort by creation date' => '作成日順で並べる',
    'Sort by update date' => '更新日順で並べる',
    'Test message' => 'テスト メッセージ',
    'Theme' => 'テーマ',
    'These settings refer to advanced topics of your social network.' => 'ここでは、ソーシャルネットワークの高度な設定を行うことができます。',
    'These settings refer to the appearance of your social network.' => 'ここでは、ソーシャルネットワークの外観の設定を行うことができます。',
    'Url Pattern' => 'URL パターン',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => 'URLのプレースホルダに%url%を使用します。書式はJSONである必要があります。 （例：http://www.youtube.com/oembed?url=%url%&amp;format=json）',
    'Use SMTPS' => 'SMTPSを使う',
    'Use X-Sendfile for File Downloads' => 'ファイルダウンロードのためにX-Sendfileを使用する',
    'User' => 'ユーザー',
    'User Display Name' => 'ユーザー表示名',
    'User Display Name Subtitle' => 'ユーザー表示名 サブタイトル',
    'User Settings' => 'ユーザー設定',
    'Username' => 'ユーザー名',
    'Username (e.g. john)' => 'ユーザー名（例：john）',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => 'すべてのレンダリングされたページに追加される統計HTMLコードスニペットを追加できます。',
    'You can find more configuration options here:' => 'ここでその他の構成オプションを見つけることができます。',
    'You\'re using no icon at the moment. Upload your logo now.' => '現在、アイコンを使用していません。今すぐアイコンをアップロードしてください。',
    'You\'re using no logo at the moment. Upload your logo now.' => '現在、ロゴを使用していません。今すぐロゴをアップロードしてください。',
    'e.g. 25 (for SMTP) or 465 (for SMTPS)' => '例：25 (SMTP) or 465 (SMTPS)',
    'e.g. localhost' => '例：localhost',
    'e.g. smtps://user:pass@smtp.example.com:port' => '例：smtps://user:pass@smtp.example.com:port',
    'never' => 'なし',
    'Inserted script tags must contain a nonce. e.g. {code}' => '',
];
